@@ -1,13 +1,11 @@
 import logging
 import os
-from datetime import datetime
 from logging.handlers import RotatingFileHandler
 
 from colorlog import ColoredFormatter
 
 
 LOGGER = logging.getLogger(__name__)
-LOGGERS = {}
 
 
 class DuplicateFilter(logging.Filter):
@@ -28,23 +26,16 @@ class DuplicateFilter(logging.Filter):
         return False
 
 
-class WrapperLogFormatter(ColoredFormatter):
-    def formatTime(self, record, datefmt=None):  # noqa: N802
-        return datetime.fromtimestamp(record.created).isoformat()
-
-
 def get_logger(name):
-    if LOGGERS.get(name):
-        return LOGGERS.get(name)
-
     log_level = os.environ.get("OPENSHIFT_PYTHON_WRAPPER_LOG_LEVEL", "INFO")
     log_file = os.environ.get("OPENSHIFT_PYTHON_WRAPPER_LOG_FILE", "")
     if log_level not in ["DEBUG", "INFO", "WARNING", "ERROR", "CRITICAL"]:
         raise ValueError(f"Invalid log level: {log_level}")
 
     logger_obj = logging.getLogger(name)
-    log_formatter = WrapperLogFormatter(
-        fmt="%(asctime)s %(name)s %(log_color)s%(levelname)s%(reset)s %(message)s",
+    log_formatter = ColoredFormatter(
+        fmt="%(name)s %(asctime)s %(log_color)s%(levelname) s%(reset)s %(message)s",
+        datefmt="%Y-%m-%d %H:%M:%S",
         log_colors={
             "DEBUG": "cyan",
             "INFO": "green",
@@ -57,9 +48,11 @@ def get_logger(name):
 
     console_handler = logging.StreamHandler()
     console_handler.setFormatter(fmt=log_formatter)
+    console_handler.addFilter(filter=DuplicateFilter())
 
     logger_obj.addHandler(hdlr=console_handler)
     logger_obj.setLevel(level=log_level)
+    logger_obj.addFilter(filter=DuplicateFilter())
 
     if log_file:
         log_handler = RotatingFileHandler(
@@ -70,5 +63,4 @@ def get_logger(name):
         logger_obj.addHandler(hdlr=log_handler)
 
     logger_obj.propagate = False
-    LOGGERS[name] = logger_obj
     return logger_obj
